==> gengetopt-2.15.tar.gz: gengetopt-2.15/src/parser.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_PACKAGE = 258,
     TOK_VERSION = 259,
     TOK_OPTION = 260,
     TOK_DEFGROUP = 261,
     TOK_GROUPOPTION = 262,
     TOK_YES = 263,
     TOK_NO = 264,
     TOK_ON = 265,
     TOK_OFF = 266,
     TOK_FLAG = 267,
     TOK_PURPOSE = 268,
     TOK_DEFAULT = 269,
     TOK_GROUP = 270,
     TOK_GROUPDESC = 271,
     TOK_MULTIPLE = 272,
     TOK_ARGOPTIONAL = 273,
     TOK_TYPESTR = 274,
     TOK_SECTION = 275,
     TOK_SECTIONDESC = 276,
     TOK_VALUES = 277,
     TOK_HIDDEN = 278,
     TOK_DEPENDON = 279,
     TOK_STRING = 280,
     TOK_MLSTRING = 281,
     TOK_CHAR = 282,
     TOK_ARGTYPE = 283
   };
#endif
#define TOK_PACKAGE 258
#define TOK_VERSION 259
#define TOK_OPTION 260
#define TOK_DEFGROUP 261
#define TOK_GROUPOPTION 262
#define TOK_YES 263
#define TOK_NO 264
#define TOK_ON 265
#define TOK_OFF 266
#define TOK_FLAG 267
#define TOK_PURPOSE 268
#define TOK_DEFAULT 269
#define TOK_GROUP 270
#define TOK_GROUPDESC 271
#define TOK_MULTIPLE 272
#define TOK_ARGOPTIONAL 273
#define TOK_TYPESTR 274
#define TOK_SECTION 275
#define TOK_SECTIONDESC 276
#define TOK_VALUES 277
#define TOK_HIDDEN 278
#define TOK_DEPENDON 279
#define TOK_STRING 280
#define TOK_MLSTRING 281
#define TOK_CHAR 282
#define TOK_ARGTYPE 283




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 97 "parser.yy"
typedef union YYSTYPE {
    char   *str;
    char    chr;
    int	    argtype;
    int	    boolean;
    class AcceptedValues *ValueList;
    struct gengetopt_option *gengetopt_option;
} YYSTYPE;
/* Line 1285 of yacc.c.  */
#line 102 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

#if ! defined (YYLTYPE) && ! defined (YYLTYPE_IS_DECLARED)
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

extern YYLTYPE yylloc;

==> gengetopt-2.17.tar.gz: gengetopt-2.17/src/parser.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     TOK_PACKAGE = 258,
     TOK_VERSION = 259,
     TOK_OPTION = 260,
     TOK_DEFGROUP = 261,
     TOK_GROUPOPTION = 262,
     TOK_YES = 263,
     TOK_NO = 264,
     TOK_ON = 265,
     TOK_OFF = 266,
     TOK_FLAG = 267,
     TOK_PURPOSE = 268,
     TOK_DEFAULT = 269,
     TOK_GROUP = 270,
     TOK_GROUPDESC = 271,
     TOK_MULTIPLE = 272,
     TOK_ARGOPTIONAL = 273,
     TOK_TYPESTR = 274,
     TOK_SECTION = 275,
     TOK_SECTIONDESC = 276,
     TOK_VALUES = 277,
     TOK_HIDDEN = 278,
     TOK_DEPENDON = 279,
     TOK_STRING = 280,
     TOK_MLSTRING = 281,
     TOK_CHAR = 282,
     TOK_ARGTYPE = 283,
     TOK_SIZE = 284
   };
#endif
/* Tokens.  */
#define TOK_PACKAGE 258
#define TOK_VERSION 259
#define TOK_OPTION 260
#define TOK_DEFGROUP 261
#define TOK_GROUPOPTION 262
#define TOK_YES 263
#define TOK_NO 264
#define TOK_ON 265
#define TOK_OFF 266
#define TOK_FLAG 267
#define TOK_PURPOSE 268
#define TOK_DEFAULT 269
#define TOK_GROUP 270
#define TOK_GROUPDESC 271
#define TOK_MULTIPLE 272
#define TOK_ARGOPTIONAL 273
#define TOK_TYPESTR 274
#define TOK_SECTION 275
#define TOK_SECTIONDESC 276
#define TOK_VALUES 277
#define TOK_HIDDEN 278
#define TOK_DEPENDON 279
#define TOK_STRING 280
#define TOK_MLSTRING 281
#define TOK_CHAR 282
#define TOK_ARGTYPE 283
#define TOK_SIZE 284




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 118 "parser.yy"
typedef union YYSTYPE {
    char   *str;
    char    chr;
    int	    argtype;
    int	    boolean;
    class AcceptedValues *ValueList;
    struct gengetopt_option *gengetopt_option;
    struct multiple_size *multiple_size;
} YYSTYPE;
/* Line 1447 of yacc.c.  */
#line 106 "parser.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;

#if ! defined (YYLTYPE) && ! defined (YYLTYPE_IS_DECLARED)
typedef struct YYLTYPE
{
  int first_line;
  int first_column;
  int last_line;
  int last_column;
} YYLTYPE;
# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
# define YYLTYPE_IS_DECLARED 1
# define YYLTYPE_IS_TRIVIAL 1
#endif

extern YYLTYPE yylloc;
